#!/bin/bash
source "${AGENT_PATH}/common.sh"
_check_required_env_vars "LOCAL_DATA_FOLDER" "IMAGE_REGISTRY" "IMAGE_REPO" "IMAGE_TAG" "CONTAINER_NAME"

# Nginx Example Install Script

# Ensure local data folder exists
datacreate "path=${LOCAL_DATA_FOLDER}"

if [ -z "$( ls -A "${LOCAL_DATA_FOLDER}" )" ]; then
    echo "Creating default index.html file..."
    echo "<html><body><h1>Hello, World, this is ${CONTAINER_NAME}!</h1></body></html>" > "${LOCAL_DATA_FOLDER}/index.html"
fi

echo "Checking Docker installation..."
_check_docker_installed || _die "Docker test failed, aborting installation..."

echo "Pulling image ${IMAGE_REGISTRY}/${IMAGE_REPO}:${IMAGE_TAG}..."
docker pull "$IMAGE_REGISTRY/$IMAGE_REPO:$IMAGE_TAG" || _die "Failed to pull image $IMAGE_REGISTRY/$IMAGE_REPO:$IMAGE_TAG"

echo "Stopping and removing any existing container..."
./stop.sh || _die "Failed to stop container ${CONTAINER_NAME}"
_remove_container $CONTAINER_NAME || _die "Failed to remove container ${CONTAINER_NAME}"

echo "Starting container..."
./start.sh || _die "Failed to start container ${CONTAINER_NAME}"

echo "Installation complete for service ${CONTAINER_NAME}."
